Learn R Programming

GFGM.copula (version 1.0.4)

Dependence.GFGM: Bivariate dependence measures under the generalized FGM copula

Description

Compute Kendall's tau and Spearman's rho with their boundaries under the generalized FGM copula.

Usage

Dependence.GFGM(p, q, theta)

Arguments

p

Copula parameter that greater than or equal to 1.

q

Copula parameter that greater than 1.

theta

Copula parameter with restricted range.

Value

theta

Dependence parameter.

tau

Kendall's tau.

rho

Spearman's rho.

Details

The admissible range of theta (\(\theta\)) is $$-\min\bigg\{1,\frac{1}{p^{2q}}\bigg(\frac{1+pq}{q-1}\bigg)^{2q-2}\bigg\} \leq \theta \leq \frac{1}{p^{q}}\bigg(\frac{1+pq}{q-1}\bigg)^{q-1}.$$ See also Shih and Emura (2019) for details.

References

Shih J-H, Emura T (2019) Bivariate dependence measures and bivariate competing risks models under the generalized FGM copula, Statistical Papers, 60:1101-1118.

Examples

Run this code
# NOT RUN {
library(GFGM.copula)
Dependence.GFGM(3,2,0.75)
# }

Run the code above in your browser using DataLab