GFGM.BurrIII: Generate samples from the generalized FGM copula with the Burr III margins
Description
Generate samples from the generalized FGM copula with the Burr III margins.
Usage
GFGM.BurrIII(n, p, q, theta, Alpha, Beta, Gamma)
Arguments
n
Sample size.
p
Copula parameter that greater than or equal to 1.
q
Copula parameter that greater than 1.
theta
Copula parameter with restricted range.
Alpha
Positive shape parameter for the Burr III margin.
Beta
Positive shape parameter for the Burr III margin.
Gamma
Common positive shape parameter for the Burr III margins.
Value
X
X is asscoiated with the parameter Alpha.
Y
Y is asscoiated with the parameter Beta.
Details
The admissible range of theta is given in Dependence.GFGM.
References
Shih J-H, Emura T (2018) Likelihood-based inference for bivariate latent failure time models with competing risks udner the generalized FGM copula, Computational Statistics, 33:1293-1323.
Shih J-H, Emura T (2019) Bivariate dependence measures and bivariate competing risks models under the generalized FGM copula, Statistical Papers, 60:1101-1118.