Sdist.GFGM.BurrIII: Sub-distribution functions under the generalized FGM copula with the Burr III margins
Description
Sub-distribution functions under the generalized FGM copula with the Burr III margins.
Usage
Sdist.GFGM.BurrIII(time, Alpha, Beta, Gamma, p, q, theta, eta = 0)
Arguments
time
Vector of times.
Alpha
Positive shape parameter for the Burr III margin (failure cause 1).
Beta
Positive shape parameter for the Burr III margin (failure cause 2).
Gamma
Common positive shape parameter for the Burr III margins.
p
Copula parameter that greater than or equal to 1.
q
Copula parameter that greater than 1 (integer).
theta
Copula parameter with restricted range.
eta
Location parameter with default value 0.
Value
time
Failure times
Sdist.1
Probability of an object fails due to the failure cause 1.
Sdist.2
Probability of an object fails due to the failure cause 2.
Details
The copula parameter q is restricted to be a integer due to the binominal theorem.
The admissible range of theta is given in Dependence.GFGM.
References
Shih J-H, Emura T (2018) Likelihood-based inference for bivariate latent failure time models with competing risks udner the generalized FGM copula, Computational Statistics, 33:1293-1323.
Shih J-H, Emura T (2019) Bivariate dependence measures and bivariate competing risks models under the generalized FGM copula, Statistical Papers, 60:1101-1118.