Sdist.GFGM.spline: Sub-distribution functions under the generalized FGM copula with the marginal distributions approximated by splines
Description
Sub-distribution functions under the generalized FGM copula with the marginal distributions approximated by splines.
Usage
Sdist.GFGM.spline(time, g1, g2, tmin, tmax, p, q, theta)
Arguments
time
Vector of times.
g1
Splines coefficients for the failure cause 1.
g2
Splines coefficients for the failure cause 2.
tmin
Lower bound of times.
tmax
upper bound of times.
p
Copula parameter that greater than or equal to 1.
q
Copula parameter that greater than 1 (integer).
theta
Copula parameter with restricted range.
Value
time
Failure times
Sdist.1
Probability of an object fails due to the failure cause 1.
Sdist.2
Probability of an object fails due to the failure cause 2.
Details
The splines coefficients g1 and g2 are usually computed by MLE.GFGM.spline.
The copula parameter q is restricted to be a integer due to the binominal theorem.
The admissible range of theta is given in Dependence.GFGM.
References
Shih J-H, Emura T (2018) Likelihood-based inference for bivariate latent failure time models with competing risks udner the generalized FGM copula, Computational Statistics, 33:1293-1323.
Shih J-H, Emura T (2019) Bivariate dependence measures and bivariate competing risks models under the generalized FGM copula, Statistical Papers, 60:1101-1118.